class FileNotFoundError(Exception):
    """
        Exception raised when file does not exists.
        Attributes:
            entity -- name of the entity that file represents
            date -- 
    """
    def __init__(self, entity, date):
        self.entity = entity
        self.date = date
    def __str__(self):
        return f"No files found for {self.entity} on date {self.date}."


class ColumnNotFoundError(Exception):
    """
        Exception raised when column of file does not exists.
        Attributes:
            entity -- name of the entity
            column -- name of the column
    """
    def __init__(self, entity, column):
        self.entity = entity
        self.column = column


class ClientResponseError(Exception):
    """
        Exception raised when client service return an error
        Attributes:
            name -- error name
            status_code -- http response error code
    """
    def __init__(self, name, status_code):
        self.name = name
        self.status_code = status_code


class ApiResponseError(Exception):
    """
        Exception raised when client service return an error
        Attributes:
            name -- error name
            status_code -- http response error code
    """
    def __init__(self, name, status_code):
        self.name = name
        self.status_code = status_code


class SaveFileError(Exception):
    """
        Exception raised when save a file with data loaded return an error
        Attributes:
            entity -- name of the entity that file represents
    """
    def __init__(self, entity):
        self.entity = entity




import json
import sys
import random
import requests
from utils import Singleton

class Slack(metaclass=Singleton):
    def __init__(self, web_hook):
        self.web_hook = web_hook

    def send_alert(self, title, message):
        url = self.web_hook
        message = message
        title = title
        slack_data = {
            "username": "NotificationBot",
            "icon_emoji": ":satellite:",
            "channel" : "#integration-alerts",
            "attachments": [
                {
                    "color": "#9733EE",
                    "fields": [
                        {
                            "title": title,
                            "value": message,
                            "short": "false",
                        }
                    ]
                }
            ]
        }
        byte_length = str(sys.getsizeof(slack_data))
        headers = {'Content-Type': "application/json", 'Content-Length': byte_length}
        response = requests.post(url, data=json.dumps(slack_data), headers=headers)
        if response.status_code != 200:
            raise Exception(response.status_code, response.text)



# Import our newly installed setuptools package.
import setuptools

# Opens our README.md and assigns it to long_description.
with open("README.md", "r") as fh:
	long_description = fh.read()

# Defines requests as a requirement in order for this package to operate. The dependencies of the project.
requirements = ["requests==2.25.0", "bunyan==0.1.2"]

# Function that takes several arguments. It assigns these values to our package.
setuptools.setup(
	# Distribution name the package. Name must be unique so adding your username at the end is common.
	name="common_integration_yom",
	# Version number of your package. Semantic versioning is commonly used.
	version="0.0.4",
	# Author name.
	author="Yom",
	# Author's email address.
	author_email="data@youorder.me",
	# Short description that will show on the PyPi page.
	description="A common integration package",
	# Long description that will display on the PyPi page. Uses the repo's README.md to populate this.
	long_description=long_description,
	# Defines the content type that the long_description is using.
	long_description_content_type="text/markdown",
	# The URL that represents the homepage of the project. Most projects link to the repo.
	url="https://github.com/ericjaychi/sample-pypi-package",
	# Finds all packages within in the project and combines them into the distribution together.
	packages=setuptools.find_packages(),
	# requirements or dependencies that will be installed alongside your package when the user installs it via pip.
	install_requires=requirements,
	# Gives pip some metadata about the package. Also displays on the PyPi page.
	classifiers=[
		"Programming Language :: Python :: 3.8",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	# The version of Python that is required.
	python_requires='>=3.6',
)